@@ -551,7 +551,7 @@
 #' @importFrom splines splineDesign
 #' @examples
 #'
-#' \donttest{
+#' \dontrun{
 #' # Generation of data to use
 #' data.sim <- jointSurrSimul(n.obs=600, n.trial = 30,cens.adm=549.24,
 #'          alpha = 1.5, theta = 3.5, gamma = 2.5, zeta = 1, sigma.s = 0.7,
@@ -622,9 +622,9 @@
 #' # select 20% of the original dataset
 #' set.seed(1)
 #' n<-nrow(gastadj)
-#' subset<-gastadj[sort(sample(1:nrow(gastadj),round(n*0.2),replace = F)),]
+#' subset<-gastadj[sort(sample(1:nrow(gastadj),round(n*0.2),replace = FALSE)),]
 #'
-#' # Mediation model ('mediation=T'). Computation takes around 17 minutes
+#' # Mediation model ('mediation=TRUE'). Computation takes around 17 minutes
 #' mod.gast<-jointSurroPenal(subset,n.knots = 4,indicator.zeta = 0,
 #'                          indicator.alpha = 0,mediation=TRUE,g.nknots=1,
 #'                          rt.ntimes=30,rt.nmc=10000,rt.boot=FALSE)
@@ -636,7 +636,7 @@
 #  # and computation of the confidence bands computed for the function R(t)
 #  # and the natural effects. Computation may take more than 40 minutes.
 #' # mod.gast2<-jointSurroPenal(gastadj,n.knots = 4,mediation=TRUE,g.nknots=1,
-#' #                            rt.ntimes=30,rt.nmc=10000,rt.boot=T,
+#' #                            rt.ntimes=30,rt.nmc=10000,rt.boot=TRUE,
 #' #                            rt.nboot=2000,rt.boot.nmc=10000)
 #'
 #' # results
@@ -948,7 +948,7 @@ jointSurroPenal = function(data,maxit = 50, indicator.zeta = 1, indicator.alpha
       #kappa0 <- frailtypack:::kappa_val_croisee(don_S=donnees,don_T=death,njeu=1,n_obs=nsujet1,n_node=n.knots,adjust_S=1,adjust_T=1,kapp_0 = 0)
       kappa0 <- kappa_val_croisee(don_S=donnees,don_T=death,njeu=1,n_obs=nsujet1,n_node=n.knots,adjust_S=1,adjust_T=1,kapp_0 = 0, print.times = F, scale = scale)
       # I deleate the created text file
-      file.remove(dir(pattern="kappa_valid_crois.txt"))
+      #file.remove(dir(pattern="kappa_valid_crois.txt"))
     }
     # else, we use the kappa give by the user
   }else{
