@@ -14,7 +14,8 @@ mergeJointSurroSimul = function(nb.packet = 2, envir.name = "joint.simul2_", env
   # envir.name = the main part of the .RData names
   # envir.num.base = the reference number of the packets
   # wd = the work directory that contains the .RData files
-  
+  oldwd<-getwd()
+  on.exit(setwd(oldwd))
   setwd(wd)
   filename <- paste(envir.name, envir.num.base,1, ".RData", sep = "")
   load(filename)
