@@ -21,7 +21,8 @@
 "print.jointPenal" <- function (x, digits = max(options()$digits - 4, 6), ...) 
 {
   
-  
+oldpar <- par(no.readonly = TRUE) 
+on.exit(par(oldpar))
 
 if(is.null(x$family)){ 
   
