@@ -994,6 +994,12 @@
             double precision::sudc
         double precision::lamdc,temp,lam, tempscl
         
+        nn = 0 
+
+        sudc= 0.0d0 
+        su = 0.d0 
+        sut1 = 0.d0 
+        sut0 = 0.0d0 
         upper = .false.
         ss=0.d0
             
