@@ -1,10 +1,10 @@
 #include <R.h>
 #include <Rinternals.h>
 
-void F77_SUB(updaterandomseed)(int seed) {
+void F77_SUB(updaterandomseed)(int *seed) {
   SEXP setSeedFunc, arg;
   PROTECT(setSeedFunc = findFun(install("set.seed"), R_GlobalEnv));
-  PROTECT(arg = ScalarInteger(seed));
+  PROTECT(arg = ScalarInteger(*seed));
   eval(lang2(setSeedFunc, arg), R_GlobalEnv);
   UNPROTECT(2);
 }
