@@ -47,7 +47,7 @@ double precision function funcpajlongisplines2(b,np,id,thi,jd,thj,k0)
   !AD:end
   double precision,dimension(0:ndatemax)::ut1
   double precision,dimension(0:ndatemaxdc)::ut2
-  double precision::int,eps
+  double precision::int_v2,eps_v2
   double precision,parameter::pi=3.141592653589793d0
   double precision,dimension(:,:),allocatable :: mat_sigma,varcov_marg_inv
   double precision,dimension(:),allocatable :: matv
@@ -106,11 +106,18 @@ double precision function funcpajlongisplines2(b,np,id,thi,jd,thj,k0)
   !double precision::fixed_Binary
   !integer::GLMloglink0,MTP0
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-  real::tstart,tstop  
-
+  !real::tstart,tstop 
   !$ integer::nthreads 
-  method_int=1
+  funcpajlongisplines2 = 0.d0 
   
+  method_int=1
+  if(.false.) then 
+    betazm = betazm 
+    betazt = betazt 
+    betaztime=betaztime
+    matmc_frail=matmc_frail 
+    nmcfrail = nmcfrail
+  end if 
   !$ nthreads = omp_get_max_threads()
 
   !call cpu_time(tstart)
@@ -475,8 +482,8 @@ double precision function funcpajlongisplines2(b,np,id,thi,jd,thj,k0)
                       end do
                     end do
                     ier = 0
-                    eps = 1.d-10
-                    call dsinvj(matv,nmescurOMP,eps,ier)
+                    eps_v2 = 1.d-10
+                    call dsinvj(matv,nmescurOMP,eps_v2,ier)
                     varcov_marg_inv=0.d0
                     do j=1,nmescurOMP
                       do kk=1,nmescurOMP
@@ -531,12 +538,12 @@ double precision function funcpajlongisplines2(b,np,id,thi,jd,thj,k0)
                           !nodes_number=1
                           !call gauherJ22OMP(int,choix,nodes_number,numpatOMP,&
                           !                  nmescurOMP,ut2curOMP,muOMP,ycurrentOMP,it_curOMP,Z1OMP)
-                          call dummyMCOMP(int,numpatOMP,&
+                          call dummyMCOMP(int_v2,numpatOMP,&
                           nmescurOMP,ut2curOMP,muOMP,ycurrentOMP,it_curOMP,Z1OMP)
                         !end if
                       end if
                       deallocate(mu1)
-                      integrale4(ig) =int !result(1) !
+                      integrale4(ig) =int_v2
                     end if
                   end if
                   it_rec = it_rec + nmescurOMP
