@@ -7,7 +7,7 @@
     im3,im2,im1,im,mm3dc,mm2dc,mm1dc,mmdc,im3dc,im2dc,im1dc,imdc,date,datedc,zi,&
     c,cdc,nt0,nt1,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst, &
     effet,stra,ve,vedc,pe,ng,g,nig,indic_ALPHA,ALPHA,theta,nstRec,k0T, &
-    auxig,aux1,aux2,res1,res3,kkapa,resnonpen,wtsvec
+    auxig,aux1,aux2,res1,res3,kkapa,resnonpen,wtsvec,nb_gl
     use residusM
     !use comongroup,only:the1
     use comongroup,only:vet,vet2,the2
@@ -269,7 +269,7 @@
     do ig=1,ng
         auxig=ig
         choix = 3
-        call gaulagJ(int,choix)
+        call gaulagJ(int,choix,nb_gl)
         integrale3(ig) = int !moins bon
     end do
 !************* FIN INTEGRALES **************************
