@@ -17,7 +17,7 @@ module natural_effects
   integer,private::integ_type
   double precision,dimension(:,:),allocatable,save,private::vectgamma
   double precision::sig_s,sig_t,sig_st,sig_omega,sig_u,eta_ind,alpha_ind
-  double precision,dimension(:),allocatable,private::vls,vss,vlt,vst,tS,tT
+  double precision,dimension(:),allocatable,private::vls2,vss2,vlt2,vst2,tS2,tT2
   double precision,dimension(30),parameter,private::lag_nodes=(/0.04740718d0,&
                 0.24992392d0,0.61483345d0,1.14319583d0,1.83645455d0,&
                 2.69652187d0,3.72581451d0,4.92729377d0,6.30451559d0,&
@@ -42,15 +42,13 @@ module natural_effects
       implicit none
       integer,dimension(10)::nparams
       integer::np
-      integer::nsplines
+      integer::nsplines2
       integer::boot
       double precision,dimension(ntimes)::times
       double precision,dimension(ntimes,4,1+boot*nboot),intent(out)::res
-      double precision,dimension(2,2)::sigma_ind
       double precision,dimension(2+nparams(7))::knots
       integer::i,j
       integer::integ
-      double precision::s
       double precision::xx1,xx2,xx3
       double precision,dimension(np)::b
       double precision,dimension(np,np)::covar
@@ -76,15 +74,16 @@ module natural_effects
       !np = sum(nparams)
 
       !!!!
-      allocate(vls(nparams(9)),vss(nparams(9)),vlt(nparams(10)),vst(nparams(10)))
-      allocate(tS(nparams(9)),tT(nparams(9)))
-      allocate(bgamma(nsplines))
+      nsplines2 = nparams(7)+nparams(8)
+      allocate(vls2(nparams(9)),vss2(nparams(9)),vlt2(nparams(10)),vst2(nparams(10)))
+      allocate(tS2(nparams(9)),tT2(nparams(9)))
+      allocate(bgamma(nsplines2))
       allocate(b_ind(np))
       allocate(basissplines(nparams(7)+nparams(8)))
       allocate(vectgamma(1001,2))
 
       integ_type=integ
-      nsplines = nparams(7)+nparams(8)
+      
 
       call random_params(np,nparams,b,covar,zi,knots,.FALSE.)
       !write(*,*) "Computation for R(t)."
@@ -115,7 +114,7 @@ module natural_effects
         !write(*,*) "End of boostrap computing"
       end if
       deallocate(basissplines,vectgamma,b_ind,bgamma)
-      deallocate(tS,tT,vls,vss,vlt,vst)
+      deallocate(tS2,tT2,vls2,vss2,vlt2,vst2)
       return
   end subroutine
   subroutine montecarlo(t,zs,zt,nsim,result)
@@ -125,7 +124,7 @@ module natural_effects
        integer::zs,zt
        integer::nsim
        integer::i
-       double precision,dimension(2,2)::sigma,sigma2
+       double precision,dimension(2,2)::sigma
        double precision,external::h
        double precision,dimension(:,:),allocatable::x1
        double precision::result
@@ -182,9 +181,9 @@ module natural_effects
     double precision::preds,predt
     double precision::h0tt,h0ts,h0ss,l0ss,h0st
     double precision::gamma
-    double precision::dummy
     integer::zs,zt
-    integer::i,j,indic_int
+    integer::i,j,indic_int 
+    survival_t = 0.d0 
     if(s.lt.0.0d0) then
       survival_t = 0.d0
       goto 180
@@ -198,35 +197,35 @@ module natural_effects
       h0ss = 0.d0
       l0ss = 0.d0
     else
-      if(s.le.tS(1)) then
-        h0ss = -dlog(vss(1))
-        l0ss = vls(1)
-      else if (s.ge.tS(size(tS))) then
-        h0ss = -dlog(vss(size(tS)))
-        l0ss = vls(size(tS))
+      if(s.le.tS2(1)) then
+        h0ss = -dlog(vss2(1))
+        l0ss = vls2(1)
+      else if (s.ge.tS2(size(tS2))) then
+        h0ss = -dlog(vss2(size(tS2)))
+        l0ss = vls2(size(tS2))
       else
         i=0
-        do while (tS(i+1).lt.s)
+        do while (tS2(i+1).lt.s)
           i = i+1
         end do
-        h0ss = -dlog(vss(i))
-        l0ss = vls(i)
+        h0ss = -dlog(vss2(i))
+        l0ss = vls2(i)
       end if
     end if
     !h0tt
     if(time.le.0.d0) then
       h0tt = 0.0d0
     else
-      if(time.le.tT(1)) then
-        h0tt = -dlog(vst(1))
-      else if (time.ge.tT(size(tT))) then
-        h0tt = -dlog(vst(size(tT)))
+      if(time.le.tT2(1)) then
+        h0tt = -dlog(vst2(1))
+      else if (time.ge.tT2(size(tT2))) then
+        h0tt = -dlog(vst2(size(tT2)))
       else
         i=0
-        do while (tT(i+1).lt.time)
+        do while (tT2(i+1).lt.time)
           i = i+1
         end do
-        h0tt = -dlog(vst(i))
+        h0tt = -dlog(vst2(i))
       end if
     end if
 
@@ -241,16 +240,16 @@ module natural_effects
       if(s.le.0.d0)then
         h0ts = 0.0d0
       else
-        if(s.le.tT(1)) then
-          h0ts = -dlog(vst(1))
-        else if (s.ge.tT(size(tT))) then
-          h0ts = -dlog(vst(size(tT)))
+        if(s.le.tT2(1)) then
+          h0ts = -dlog(vst2(1))
+        else if (s.ge.tT2(size(tT2))) then
+          h0ts = -dlog(vst2(size(tT2)))
         else
           i=0
-          do while (tT(i+1).lt.s)
+          do while (tT2(i+1).lt.s)
             i = i+1
           end do
-          h0ts = -dlog(vst(i))
+          h0ts = -dlog(vst2(i))
         end if
       end if
       if((s.lt.boundaryknotsurro(1)).or.(s.gt.boundaryknotsurro(2)))then
@@ -271,16 +270,16 @@ module natural_effects
       if(time.le.0)then
         h0st = 0.0d0
       else
-        if(time.le.tS(1)) then
-          h0st = -dlog(vss(1))
-        else if (time.ge.tS(size(tS))) then
-          h0st = -dlog(vss(size(tS)))
+        if(time.le.tS2(1)) then
+          h0st = -dlog(vss2(1))
+        else if (time.ge.tS2(size(tS2))) then
+          h0st = -dlog(vss2(size(tS2)))
         else
           i=0
-          do while (tS(i+1).lt.time)
+          do while (tS2(i+1).lt.time)
             i = i+1
           end do
-          h0st = -dlog(vss(i))
+          h0st = -dlog(vss2(i))
         end if
       end if
       survival_t=exp(-h0tt*exp(predt))*exp(-h0st*exp(preds))
@@ -302,15 +301,15 @@ module natural_effects
     double precision,dimension(2,2)::temp_mat
     double precision,dimension(nparams(1)+4)::zi
     logical::ran
-    integer::i,j,nsplines
-    nsplines = nparams(7)+nparams(8)
+    integer::i,j,nsplines2
+    nsplines2 = nparams(7)+nparams(8)
     if(.NOT.ran)then
       b_ind = b
-      bgamma=b_ind((np-nsplines+1):np)
+      bgamma=b_ind((np-nsplines2+1):np)
       vectgamma = 0.0d0
       basissplines=0.0d0
-      bs=b_ind(np-nsplines-1)
-      bt=b_ind(np-nsplines)
+      bs=b_ind(np-nsplines2-1)
+      bt=b_ind(np-nsplines2)
       if(nparams(5).eq.1) then
         eta_ind = b_ind(nparams(1)+nparams(2)+nparams(5))
       else
@@ -345,7 +344,7 @@ module natural_effects
         end do
       end do
       call baseline_rs(nparams(1)-2,nparams(2)-2,b_ind,nparams(9),&
-                       nparams(10),zi,tS,vls,vss,tT,vlt,vst)
+                       nparams(10),zi,tS2,vls2,vss2,tT2,vlt2,vst2)
     end if
     if(ran) then
       cdummy=covar
@@ -357,11 +356,11 @@ module natural_effects
       do i=1,np
         b_ind(i) = b(i) + x1(i)
       end do
-      bgamma=b_ind((np-nsplines+1):np)
+      bgamma=b_ind((np-nsplines2+1):np)
       vectgamma = 0.0d0
       basissplines=0.0d0
-      bs=b_ind(np-nsplines-1)
-      bt=b_ind(np-nsplines)
+      bs=b_ind(np-nsplines2-1)
+      bt=b_ind(np-nsplines2)
       if(nparams(5).eq.1) then
         eta_ind = b_ind(nparams(1)+nparams(2)+nparams(5))
       else
@@ -396,22 +395,22 @@ module natural_effects
         end do
       end do
       call baseline_rs(nparams(1)-2,nparams(2)-2,b_ind,nparams(9),&
-                       nparams(10),zi,tS,vls,vss,tT,vlt,vst)
+                       nparams(10),zi,tS2,vls2,vss2,tT2,vlt2,vst2)
     end if
   end subroutine
-  subroutine baseline_rs(nz1,nz2,b,mt1,mt2,zi,tS,vls,vss,tT,vlt,vst)
+  subroutine baseline_rs(nz1,nz2,b,mt1,mt2,zi,tS3,vls3,vss3,tT3,vlt3,vst3)
     Implicit none
     integer,intent(in):: nz1,nz2,mt1,mt2
     double precision ,dimension(npmax),intent(in):: b
-    integer::i,j,n,k,l,jj
+    integer::i,j,n,k,l
     double precision::x1,x2,h,su,lam
     double precision ,dimension(-2:nz1)::the2
     double precision ,dimension(-2:nz2)::the1T
     double precision,dimension(-2:(nz1+3))::zi
-    double precision,dimension(mt1)::tS
-    double precision,dimension(mt2)::tT
-    double precision,dimension(mt1)::vls,vss
-    double precision,dimension(mt2)::vlt,vst
+    double precision,dimension(mt1)::tS3
+    double precision,dimension(mt2)::tT3
+    double precision,dimension(mt1)::vls3,vss3
+    double precision,dimension(mt2)::vlt3,vst3
     n  = nz1+2
     k = 0
     do i=1,(nz1+2)
@@ -443,9 +442,9 @@ module natural_effects
                 x1 = x1 + h
             end if
             call calcul_rs(x1,the1T,nz1+2,zi,su,lam)
-            tS(i)=x1
-            vls(i)=lam
-            vss(i)=su
+            tS3(i)=x1
+            vls3(i)=lam
+            vss3(i)=su
         end do
     x2 = zi(1)
     do i=1,mt2
@@ -453,9 +452,9 @@ module natural_effects
             x2 = x2 + h
         endif
         call calcul_rs(x2,the2,nz2+2,zi,su,lam)
-        tT(i)=x2
-        vlt(i)=lam
-        vst(i)=su
+        tT3(i)=x2
+        vlt3(i)=lam
+        vst3(i)=su
     end do
     return
   end subroutine baseline_rs
@@ -467,7 +466,7 @@ module natural_effects
     double precision,dimension(-2:(n-2)),intent(in)::the
     double precision,dimension(-2:(n+1))::zi
     integer::j,k,i
-    double precision::ht,ht2,h2,som,pm,htm,h2t,h3,h2n,hn, &
+    double precision::ht,ht2,h2,som,htm,h2t,h3,h2n,hn, &
     im,im1,im2,mm1,mm3,ht3,hht,h4,h3m,hh3,hh2,mm,im3,mm2, &
     h,gl,hh
     j=0
@@ -603,8 +602,10 @@ module natural_effects_longi
               X1=UNIRAN()
               X2=UNIRAN()
           else !on generer avec RANDOM_NUMBER(avec gestion du seed garanti)
-              CALL RANDOM_NUMBER(X1)
-              CALL RANDOM_NUMBER(X2)
+              !CALL RANDOM_NUMBER(X1)
+              !CALL RANDOM_NUMBER(X2)
+              X1=UNIRAN()
+              X2=UNIRAN()
           endif
 
           IF(ID.NE.1) GO TO 10
@@ -874,7 +875,8 @@ module natural_effects_longi
           w=matmul(w,chol1)
       end if 
       result=0.0d0
-      !$omp parallel do default(none) private(i) shared(t,w,nu,zm,zt,nparams,params,tT,vst,res)
+      !$omp parallel do default(none) private(i) shared(nsim,t,w,nu,zm,zt, &
+      !$omp nparams,params,tT,vst,res)
       do i=1,nsim
         call survival_t(t,w(i,1),w(i,2),nu(i,1),nu(i,2),zm,zt,nparams,params,tT,vst,res(i))
       enddo
@@ -886,7 +888,7 @@ module natural_effects_longi
   subroutine survival_t(time,w0,w1,nu_m,nu_t,zm,zt,nparams,params,tT,vst,res)
       IMPLICIT NONE
       integer,dimension(9)::nparams
-      double precision::time,s
+      double precision::time
       double precision::w0,w1,nu_m,nu_t
       double precision,dimension(8)::params
       integer::zm,zt
@@ -1124,7 +1126,7 @@ module natural_effects_longi
       double precision,dimension(-2:(n-2)),intent(in)::the
       double precision,dimension((n+4))::zi
       integer::j,k,i
-      double precision::ht,ht2,h2,som,pm,htm,h2t,h3,h2n,hn, &
+      double precision::ht,ht2,h2,som,htm,h2t,h3,h2n,hn, &
       im,im1,im2,mm1,mm3,ht3,hht,h4,h3m,hh3,hh2,mm,im3,mm2, &
       h,gl,hh
       j=0
